@@ -18,7 +18,7 @@
 """
 
 
-class JSONConvert():
+class JSONConvert(object):
     # This magic number is work around.
     # Body size limitation with PUT method,
     # The boudnary of body size in over 27915 byte and under 27938 byte.
@@ -29,6 +29,7 @@ class JSONConvert():
         self.split_index = 0
         self.records = []
         self.separated_list = []
+        self.delta = False
 
     def readRecords(self, listitems):
         import re
@@ -64,7 +65,6 @@ class JSONConvert():
         return v
 
     def genData(self, act):
-        import json
         data = lambda act: {"records": self.records} \
             if act else {"name": self.domain, "records": self.records}
         self.dict_records = data(act)
@@ -74,10 +74,15 @@ class JSONConvert():
         import re
         line_index = 1
         separated_str = ''
+        if self.delta:
+            # for test only
+            delta = self.delta
+        else:
+            delta = self.maxdata
 
         for line in file:
             if not re.search('^#', line):
-                if line_index > self.maxdata:
+                if line_index > delta:
                     line_index = 1
                     self.split_index += 1
                     self.separated_list.append(separated_str)
